@@ -285,16 +285,17 @@ sub span { @_ }
 
 sub duration { 
     my $dur;
-    eval { $dur = $_[0]->end->subtract_datetime_absolute( $_[0]->start ) };
-    return $dur if defined $dur;
-
-    # TODO: shouldn't need this:
 
+    eval {
+        local $SIG{__DIE__};   # don't want to trap this (rt ticket 5434)
+        $dur = $_[0]->end->subtract_datetime_absolute( $_[0]->start )
+    };
     $@ = undef;  # clear the eval() error message
+    
+    return $dur if defined $dur;
 
     return DateTime::Infinite::Future->new -
            DateTime::Infinite::Past->new;
-    # return INFINITY;
 }
 *size = \&duration;
 
